@@ -41,8 +41,6 @@
 
 #define KCMUTILSCORE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KCMUTILSCORE_NO_DEPRECATED) && !defined(KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KCMUTILSCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCMUTILSCORE_NO_DEPRECATED
-#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KCMUTILSCORE_NO_DEPRECATED_WARNINGS
 #  define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KCMUTILSCORE_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KCMUTILSCORE_DEPRECATED
-#  define KCMUTILSCORE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCMUTILSCORE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCMUTILSCORE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCMUTILSCORE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
